@@ -1,8 +1,9 @@
 package WebService::Solr::Response;
 
 use Moose;
-use WebService::Solr::Document;
 
+use WebService::Solr::Document;
+use Data::Page;
 use JSON::XS ();
 
 has 'raw_response' => (
@@ -56,6 +57,10 @@ sub _build_pager {
     return $pager;
 }
 
+sub facet_counts {
+    return  shift->content->{ facet_counts };
+}
+
 sub solr_status {
     return shift->content->{ responseHeader }->{ status };
 }
@@ -87,7 +92,7 @@ WebService::Solr::Response - Parse responses from Solr
 
 =head1 DESCRIPTION
 
-This class encapsulates reponses from the Solr Web Service. Typically it is
+This class encapsulates responses from the Solr Web Service. Typically it is
 used when documents are returned from a search query, though it will accept
 all responses from the service.
 
@@ -116,9 +121,13 @@ required.
 
 A Moose override to allow our custom constructor.
 
+=head2 facet_counts( )
+
+A shortcut to the C<facet_counts> key in the response data.
+
 =head2 solr_status( )
 
-Looks for the status value in the respons data.
+Looks for the status value in the response data.
 
 =head2 ok( )
 
